==> agordejo_0.1.1.orig.tar.gz: agordejo-0.1.1/engine/config.py <==
#! /usr/bin/env python3
# -*- coding: utf-8 -*-

#Do not change these during runtime!

METADATA={
    #The pretty name of this program. Used for NSM display and Jack client name
    #Can contain everything a linux file/path supports. Never change this or it will break the
    #session, making your file unable to load and destroying saved Jack connections.
    "name" : "Agordejo",

    #Set this to the name the user types into a terminal.
    #MUST be the same as the binary name as well as the name in configure.
    #Program reports that as proc title so you can killall it by name.
    #Should not contain spaces or special characters. We use this as save file extension as well
    #to distinguish between compatible program versions. In basic programs this will just be e.g.
    #patroneo. But in complex programs with a bright future it will be "laborejo1" "laborejo2" etc.
    "shortName" : "agordejo",

    #A very short description used in various places: Desktop file, overview on the website,
    #release announcements, entries in software directories etc.
    "tagline" : 'Music and audio production session manager based on NSM.',

    "version" : "0.1.1",
    "year" : "2020",
    "author" : "Laborejo Software Suite",
    "url" : "https://www.laborejo.org/agordejo",

    #English is automatic.
    "supportedLanguages" : {"German":"de.qm"},

    #Show the About Dialog the first time the program starts up. This is the initial state for a
    #new instance in NSM, not the saved state! Decide on how annoying it would be for every new
    #instance to show about. Fluajho does not show it because you add it many times into a session.
    #Patroneo does because its only added once.
    "showAboutDialogFirstStart" : False,

    "preferredClients" : {"data":"nsm-data", "connections":"jackpatch", "proxy":"nsm-proxy"},

    #Various strings for the README
    #Extra whitespace will be stripped so we don't need to worry about docstring indentation
    "description" : """
Agordejo (Esperanto: 'place to set things up') is a music production session manager.
It is used to start your programs, remember their (JACK) interconnections and make your life easier
in general.
""" + "\n" + """
You can seamlessly change between two view modes to quickly start a few programs or have complete
control and a detailed overview.
""" + "\n" + """
Agordejo does not re-invent the wheel but instead uses the New-Session-Manager daemon and enhances
it with some tricks of its own, that always remain 100% compatible with the original sessions.
""" + "\n" + """
This is a proof of concept version. It aims to show that session management with NSM can be quick
and convenient and make the user feel in control. Some functionality has not yet been
implemented, most prominently anything related to NSM over network. There is always the possibility to
break things when trying out corner cases and hacks.
""" + "\n" + """
That said, for single-computer sessions with just one daemon and one GUI at the same time Agordejo
should provide a good user experience.
""", #this is the dict-comma.

    "dependencies" : "\n".join("* "+dep for dep in ("nsmd: New Session Manager", "grep")),

}

==> agordejo_0.3.1.orig.tar.gz: agordejo-0.3.1/engine/config.py <==
#! /usr/bin/env python3
# -*- coding: utf-8 -*-

#Do not change these during runtime!

METADATA={
    #The pretty name of this program. Used for NSM display and Jack client name
    #Can contain everything a linux file/path supports. Never change this or it will break the
    #session, making your file unable to load and destroying saved Jack connections.
    "name" : "Agordejo",

    #Set this to the name the user types into a terminal.
    #MUST be the same as the binary name as well as the name in configure.
    #Program reports that as proc title so you can killall it by name.
    #Should not contain spaces or special characters. We use this as save file extension as well
    #to distinguish between compatible program versions. In basic programs this will just be e.g.
    #patroneo. But in complex programs with a bright future it will be "laborejo1" "laborejo2" etc.
    "shortName" : "agordejo",

    #A very short description used in various places: Desktop file, overview on the website,
    #release announcements, entries in software directories etc.
    "tagline" : 'Music and audio production session manager based on NSM.',

    "version" : "0.3.1",
    "year" : "2022",
    "author" : "Laborejo Software Suite",
    "url" : "https://www.laborejo.org/agordejo",

    #English is automatic.
    "supportedLanguages" : {"German":"de.qm", "Italian":"it.qm", },

    #Show the About Dialog the first time the program starts up. This is the initial state for a
    #new instance in NSM, not the saved state! Decide on how annoying it would be for every new
    #instance to show about. Fluajho does not show it because you add it many times into a session.
    #Patroneo does because its only added once.
    "showAboutDialogFirstStart" : False,

    "preferredClients" : {"data":"nsm-data", "connections":"jackpatch", "proxy":"nsm-proxy"},

    #Various strings for the README
    #Extra whitespace will be stripped so we don't need to worry about docstring indentation
    "description" : """
Agordejo (Esperanto: 'place to set things up') is a music production session manager.
It is used to start your programs, remember their (JACK) interconnections and make your life easier
in general.
""" + "\n" + """
Agordejo does not re-invent the wheel but instead uses the New-Session-Manager daemon and enhances
it with some tricks of its own, that always remain 100% compatible with the original sessions.
""" + "\n" + """
This is a proof of concept version. It aims to show that session management with NSM can be quick
and convenient and make the user feel in control. Some functionality has not yet been
implemented, most prominently anything related to NSM over network. There is always the possibility to
break things when trying out corner cases and hacks.
""" + "\n" + """
That said, for single-computer sessions with just one daemon and one GUI at the same time Agordejo
should provide a good user experience.
""", #this is the dict-comma.

    "dependencies" : "\n".join("* "+dep for dep in ("nsmd: New Session Manager", "grep")),

}
